California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance Activity Propositions & Ballot Measures
Election Cycle: 2023 through 2024 Historical
All of the campaign committees that have organized to support or oppose propositions and ballot measures on California's statewide ballot are available here. Click below on the proposition or ballot measure to learn who is involved in the campaign to win your vote on Election Day.
Upcoming Elections
NOVEMBER 5, 2024, GENERAL
10 Measures
PROPOSITION 002 - AB 247 (CH. 81, 2024) MURATSUCHI. EDUCATION FINANCE: SCHOOL FACILITIES: K-12 SCHOOLS AND LOCAL COMMUNITY COLLEGE PUBLIC EDUCATION FACILITIES MODERNIZATION, REPAIR AND SAFETY BOND ACT
PROPOSITION 003 - ACA 5 (RESOLUTION CHAPTER 125, STATUTES OF 2023) LOW. MARRIAGE EQUALITY.
PROPOSITION 004 - SB 867 (CHAPTER 83, STATUTES OF 2024) ALLEN. SAFE DRINKING WATER, WILDFIRE PREVENTION, DROUGHT PREPAREDNESS, AND CLEAN AIR BOND ACT OF 2024.
PROPOSITION 005 - ACA 1 (RES. CH. 173, 2023); ACA 10 (RES. CH. 134, 2024) AGUIAR-CURRY. LOCAL GOVERNMENT FINANCING: AFFORDABLE HOUSING AND PUBLIC INFRASTRUCTURE: VOTER APPROVAL.
PROPOSITION 006 - ACA 8 (RESOLUTION CHAPTER 133, STATUTES OF 2024) WILSON. SLAVERY.
PROPOSITION 032 - RAISES MINIMUM WAGE. INITIATIVE STATUTE.
PROPOSITION 033 - EXPANDS LOCAL GOVERNMENTS' AUTHORITY TO ENACT RENT CONTROL ON RESIDENTIAL PROPERTY. INITIATIVE STATUTE.
PROPOSITION 034 - RESTRICTS SPENDING BY HEALTH CARE PROVIDERS MEETING SPECIFIED CRITERIA. INITIATIVE STATUTE.
PROPOSITION 035 - PROVIDES PERMANENT FUNDING FOR MEDI-CAL HEALTH CARE SERVICES. INITIATIVE STATUTE.
PROPOSITION 036 - ALLOWS FELONY CHARGES AND INCREASES SENTENCES FOR CERTAIN DRUG AND THEFT CRIMES. INITIATIVE STATUTE.
Prior Elections
MARCH 5, 2024, PRIMARY
1 Measure
PROPOSITION 1 - AB 531 (CHAPTER 789, STATUTES OF 2023), IRWIN. THE BEHAVIORAL HEALTH INFRASTRUCTURE BOND ACT OF 2023; SB 326 (CHAPTER 790, STATUTES OF 2023), EGGMAN. THE BEHAVIORAL HEALTH SERVICES ACT